# Changelog


## 0.4.0 (2024-06-30)

- Generalized name of model ``Website`` to ``Resource``.


## 0.3.0 (2024-05-16)

- Added optional ``attendees`` property to ``Party``.

- Added support for Python 3.12.


## 0.2.0 (2024-02-21)

- Added module to load models from TOML data.


## 0.1.0 (2024-02-21)

- Added models.
